@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-10-17'; # DATE
+our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
-our $VERSION = '0.092'; # VERSION
+our $VERSION = '0.093'; # VERSION
 
 sub meta {
     return {
@@ -49,7 +49,7 @@ Sort::Sub::changes_group_ala_perlancar - Sort changes group heading PERLANCAR-st
 
 =head1 VERSION
 
-This document describes version 0.092 of Sort::Sub::changes_group_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-10-17.
+This document describes version 0.093 of Sort::Sub::changes_group_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2024-01-08.
 
 =head1 SYNOPSIS
 
@@ -143,13 +143,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
